@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 from mvvmQt.rewriteContorls import Widget, Window, Label
 from PyQt5.QtWidgets import QWidget, QFrame, QPushButton, QGridLayout, QLayout, QHBoxLayout, QVBoxLayout, QLabel, QTabWidget\
-    , QStatusBar, QButtonGroup, QAbstractButton, QRadioButton
+    , QStatusBar, QButtonGroup, QAbstractButton, QRadioButton, QComboBox
 from mvvmQt.Observable import ObservableBase
 
 class RowOrCol:
@@ -51,6 +51,8 @@ class Element:
             'radio': [self.createRadio, self.bindAll],
             'label': [self.createLabel, self.bindAll],
             'tab': [self.createTab, self.afterCreateTab],
+            'select': [self.createCombo, self.afterCreateCombo],
+            'option': [self.createOption, None],
             'status': [self.createStatusBar, self.bindAll]
         }
 
@@ -95,8 +97,12 @@ class Element:
         else:
             ob.subscribe(lambda v: self.useQtFunc(c[0], self.changeValue(c[1], v)), init=True)
 
-    def addEvent(self, k, f):
-        getattr(self.qt, k).connect(lambda: f(self))
+    def addEvent(self, e):
+        event = getattr(self.qt, e.key)
+        if e.param:
+            event[str if e.param == 'str' else int].connect(lambda v: e.func(v, self))
+        else:
+            event.connect(lambda: e.func(self))
 
     def bindAttr(self):
         for attr in self.attrs:
@@ -114,7 +120,7 @@ class Element:
 
     def bindEvent(self):
         for e in self.events:
-            self.addEvent(e.key, e.func)
+            self.addEvent(e)
 
     def bindAll(self):
         self.bindAttr()
@@ -242,20 +248,6 @@ class Element:
     def createRadio(self):
         self.qt = QRadioButton(self.dom.text())
 
-    # def afterCreateRadio(self):
-    #     d = self.attrsToDict
-    #     if 'group' in d.keys():
-    #         gk = d['group']
-    #         if gk not in self.parser.btnGroups.keys():
-    #             self.parser.btnGroups[gk] = {
-    #                 'vqt': QButtonGroup(),
-    #                 'id': 0
-    #             }
-    #         g = self.parser.btnGroups[gk]
-    #         g['id'] += 1
-    #         g['vqt'].addButton(self.qt, g['id'])
-    #     self.bindAll()
-
     def createLabel(self):
         self.qt = Label(self.dom.text())
 
@@ -270,5 +262,17 @@ class Element:
                 tab_index += 1
         self.bindAll()
 
+    def createCombo(self):
+        self.qt = QComboBox()
+
+    def afterCreateCombo(self):
+        items = [c.qt for c in self.childs]
+        self.qt.addItems(items)
+        self.bindAll()
+
+    def createOption(self):
+        self.qt = self.dom.text()
+        self.isVitrual = True
+
     def createStatusBar(self):
         self.qt = QStatusBar()
\ No newline at end of file
